# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/upgrade/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/upgrade/v1beta1/query.proto\x12\x16\x63osmos.upgrade.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto\"\x19\n\x17QueryCurrentPlanRequest\"L\n\x18QueryCurrentPlanResponse\x12\x30\n\x04plan\x18\x01 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanR\x04plan\"-\n\x17QueryAppliedPlanRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"2\n\x18QueryAppliedPlanResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"I\n\"QueryUpgradedConsensusStateRequest\x12\x1f\n\x0blast_height\x18\x01 \x01(\x03R\nlastHeight:\x02\x18\x01\"i\n#QueryUpgradedConsensusStateResponse\x12\x38\n\x18upgraded_consensus_state\x18\x02 \x01(\x0cR\x16upgradedConsensusState:\x02\x18\x01J\x04\x08\x01\x10\x02\"=\n\x1aQueryModuleVersionsRequest\x12\x1f\n\x0bmodule_name\x18\x01 \x01(\tR\nmoduleName\"m\n\x1bQueryModuleVersionsResponse\x12N\n\x0fmodule_versions\x18\x01 \x03(\x0b\x32%.cosmos.upgrade.v1beta1.ModuleVersionR\x0emoduleVersions\"\x17\n\x15QueryAuthorityRequest\"2\n\x16QueryAuthorityResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress2\xf4\x06\n\x05Query\x12\x9e\x01\n\x0b\x43urrentPlan\x12/.cosmos.upgrade.v1beta1.QueryCurrentPlanRequest\x1a\x30.cosmos.upgrade.v1beta1.QueryCurrentPlanResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmos/upgrade/v1beta1/current_plan\x12\xa5\x01\n\x0b\x41ppliedPlan\x12/.cosmos.upgrade.v1beta1.QueryAppliedPlanRequest\x1a\x30.cosmos.upgrade.v1beta1.QueryAppliedPlanResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/upgrade/v1beta1/applied_plan/{name}\x12\xdc\x01\n\x16UpgradedConsensusState\x12:.cosmos.upgrade.v1beta1.QueryUpgradedConsensusStateRequest\x1a;.cosmos.upgrade.v1beta1.QueryUpgradedConsensusStateResponse\"I\x88\x02\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/upgrade/v1beta1/upgraded_consensus_state/{last_height}\x12\xaa\x01\n\x0eModuleVersions\x12\x32.cosmos.upgrade.v1beta1.QueryModuleVersionsRequest\x1a\x33.cosmos.upgrade.v1beta1.QueryModuleVersionsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/upgrade/v1beta1/module_versions\x12\x95\x01\n\tAuthority\x12-.cosmos.upgrade.v1beta1.QueryAuthorityRequest\x1a..cosmos.upgrade.v1beta1.QueryAuthorityResponse\")\x82\xd3\xe4\x93\x02#\x12!/cosmos/upgrade/v1beta1/authorityB\xc0\x01\n\x1a\x63om.cosmos.upgrade.v1beta1B\nQueryProtoP\x01Z\x1c\x63osmossdk.io/x/upgrade/types\xa2\x02\x03\x43UX\xaa\x02\x16\x43osmos.Upgrade.V1beta1\xca\x02\x16\x43osmos\\Upgrade\\V1beta1\xe2\x02\"Cosmos\\Upgrade\\V1beta1\\GPBMetadata\xea\x02\x18\x43osmos::Upgrade::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.upgrade.v1beta1B\nQueryProtoP\001Z\034cosmossdk.io/x/upgrade/types\242\002\003CUX\252\002\026Cosmos.Upgrade.V1beta1\312\002\026Cosmos\\Upgrade\\V1beta1\342\002\"Cosmos\\Upgrade\\V1beta1\\GPBMetadata\352\002\030Cosmos::Upgrade::V1beta1'
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._loaded_options = None
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_options = b'\030\001'
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._loaded_options = None
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_options = b'\030\001'
  _globals['_QUERY'].methods_by_name['CurrentPlan']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CurrentPlan']._serialized_options = b'\202\323\344\223\002&\022$/cosmos/upgrade/v1beta1/current_plan'
  _globals['_QUERY'].methods_by_name['AppliedPlan']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AppliedPlan']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/upgrade/v1beta1/applied_plan/{name}'
  _globals['_QUERY'].methods_by_name['UpgradedConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UpgradedConsensusState']._serialized_options = b'\210\002\001\202\323\344\223\002@\022>/cosmos/upgrade/v1beta1/upgraded_consensus_state/{last_height}'
  _globals['_QUERY'].methods_by_name['ModuleVersions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ModuleVersions']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/upgrade/v1beta1/module_versions'
  _globals['_QUERY'].methods_by_name['Authority']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Authority']._serialized_options = b'\202\323\344\223\002#\022!/cosmos/upgrade/v1beta1/authority'
  _globals['_QUERYCURRENTPLANREQUEST']._serialized_start=130
  _globals['_QUERYCURRENTPLANREQUEST']._serialized_end=155
  _globals['_QUERYCURRENTPLANRESPONSE']._serialized_start=157
  _globals['_QUERYCURRENTPLANRESPONSE']._serialized_end=233
  _globals['_QUERYAPPLIEDPLANREQUEST']._serialized_start=235
  _globals['_QUERYAPPLIEDPLANREQUEST']._serialized_end=280
  _globals['_QUERYAPPLIEDPLANRESPONSE']._serialized_start=282
  _globals['_QUERYAPPLIEDPLANRESPONSE']._serialized_end=332
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_start=334
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_end=407
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_start=409
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_end=514
  _globals['_QUERYMODULEVERSIONSREQUEST']._serialized_start=516
  _globals['_QUERYMODULEVERSIONSREQUEST']._serialized_end=577
  _globals['_QUERYMODULEVERSIONSRESPONSE']._serialized_start=579
  _globals['_QUERYMODULEVERSIONSRESPONSE']._serialized_end=688
  _globals['_QUERYAUTHORITYREQUEST']._serialized_start=690
  _globals['_QUERYAUTHORITYREQUEST']._serialized_end=713
  _globals['_QUERYAUTHORITYRESPONSE']._serialized_start=715
  _globals['_QUERYAUTHORITYRESPONSE']._serialized_end=765
  _globals['_QUERY']._serialized_start=768
  _globals['_QUERY']._serialized_end=1652
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/tx_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.evm.v1 import transaction_logs_pb2 as injective_dot_evm_dot_v1_dot_transaction__logs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/evm/v1/tx_result.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\x1a\'injective/evm/v1/transaction_logs.proto\"\x8b\x02\n\x08TxResult\x12\x46\n\x10\x63ontract_address\x18\x01 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"contract_address\"R\x0f\x63ontractAddress\x12\x14\n\x05\x62loom\x18\x02 \x01(\x0cR\x05\x62loom\x12R\n\x07tx_logs\x18\x03 \x01(\x0b\x32!.injective.evm.v1.TransactionLogsB\x16\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:\"tx_logs\"R\x06txLogs\x12\x10\n\x03ret\x18\x04 \x01(\x0cR\x03ret\x12\x1a\n\x08reverted\x18\x05 \x01(\x08R\x08reverted\x12\x19\n\x08gas_used\x18\x06 \x01(\x04R\x07gasUsed:\x04\x88\xa0\x1f\x00\x42\xd2\x01\n\x14\x63om.injective.evm.v1B\rTxResultProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.tx_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\rTxResultProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_TXRESULT'].fields_by_name['contract_address']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['contract_address']._serialized_options = b'\362\336\037\027yaml:\"contract_address\"'
  _globals['_TXRESULT'].fields_by_name['tx_logs']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['tx_logs']._serialized_options = b'\310\336\037\000\362\336\037\016yaml:\"tx_logs\"'
  _globals['_TXRESULT']._loaded_options = None
  _globals['_TXRESULT']._serialized_options = b'\210\240\037\000'
  _globals['_TXRESULT']._serialized_start=118
  _globals['_TXRESULT']._serialized_end=385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/pruning/v1/service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.services.pruning.v1 import pruning_pb2 as cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/pruning/v1/service.proto\x12\x1c\x63ometbft.services.pruning.v1\x1a*cometbft/services/pruning/v1/pruning.proto2\xfc\t\n\x0ePruningService\x12\x8d\x01\n\x14SetBlockRetainHeight\x12\x39.cometbft.services.pruning.v1.SetBlockRetainHeightRequest\x1a:.cometbft.services.pruning.v1.SetBlockRetainHeightResponse\x12\x8d\x01\n\x14GetBlockRetainHeight\x12\x39.cometbft.services.pruning.v1.GetBlockRetainHeightRequest\x1a:.cometbft.services.pruning.v1.GetBlockRetainHeightResponse\x12\xa2\x01\n\x1bSetBlockResultsRetainHeight\x12@.cometbft.services.pruning.v1.SetBlockResultsRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.SetBlockResultsRetainHeightResponse\x12\xa2\x01\n\x1bGetBlockResultsRetainHeight\x12@.cometbft.services.pruning.v1.GetBlockResultsRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.GetBlockResultsRetainHeightResponse\x12\x99\x01\n\x18SetTxIndexerRetainHeight\x12=.cometbft.services.pruning.v1.SetTxIndexerRetainHeightRequest\x1a>.cometbft.services.pruning.v1.SetTxIndexerRetainHeightResponse\x12\x99\x01\n\x18GetTxIndexerRetainHeight\x12=.cometbft.services.pruning.v1.GetTxIndexerRetainHeightRequest\x1a>.cometbft.services.pruning.v1.GetTxIndexerRetainHeightResponse\x12\xa2\x01\n\x1bSetBlockIndexerRetainHeight\x12@.cometbft.services.pruning.v1.SetBlockIndexerRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.SetBlockIndexerRetainHeightResponse\x12\xa2\x01\n\x1bGetBlockIndexerRetainHeight\x12@.cometbft.services.pruning.v1.GetBlockIndexerRetainHeightRequest\x1a\x41.cometbft.services.pruning.v1.GetBlockIndexerRetainHeightResponseB\xc3\x01\n com.cometbft.services.pruning.v1B\x0cServiceProtoP\x01\xa2\x02\x03\x43SP\xaa\x02\x1c\x43ometbft.Services.Pruning.V1\xca\x02\x1c\x43ometbft\\Services\\Pruning\\V1\xe2\x02(Cometbft\\Services\\Pruning\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Pruning::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.pruning.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.pruning.v1B\014ServiceProtoP\001\242\002\003CSP\252\002\034Cometbft.Services.Pruning.V1\312\002\034Cometbft\\Services\\Pruning\\V1\342\002(Cometbft\\Services\\Pruning\\V1\\GPBMetadata\352\002\037Cometbft::Services::Pruning::V1'
  _globals['_PRUNINGSERVICE']._serialized_start=121
  _globals['_PRUNINGSERVICE']._serialized_end=1397
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/proposal.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmwasm.wasm.v1 import proposal_legacy_pb2 as cosmwasm_dot_wasm_dot_v1_dot_proposal__legacy__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/wasmx/v1/proposal.proto\x12\x12injective.wasmx.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a&cosmwasm/wasm/v1/proposal_legacy.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"\xae\x02\n#ContractRegistrationRequestProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12y\n\x1d\x63ontract_registration_request\x18\x03 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00R\x1b\x63ontractRegistrationRequest:T\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*)wasmx/ContractRegistrationRequestProposal\"\xba\x02\n(BatchContractRegistrationRequestProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12{\n\x1e\x63ontract_registration_requests\x18\x03 \x03(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00R\x1c\x63ontractRegistrationRequests:Y\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*.wasmx/BatchContractRegistrationRequestProposal\"\xd1\x01\n#BatchContractDeregistrationProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x1c\n\tcontracts\x18\x03 \x03(\tR\tcontracts:T\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*)wasmx/BatchContractDeregistrationProposal\"\xaf\x03\n\x1b\x43ontractRegistrationRequest\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tgas_limit\x18\x02 \x01(\x04R\x08gasLimit\x12\x1b\n\tgas_price\x18\x03 \x01(\x04R\x08gasPrice\x12.\n\x13should_pin_contract\x18\x04 \x01(\x08R\x11shouldPinContract\x12\x30\n\x14is_migration_allowed\x18\x05 \x01(\x08R\x12isMigrationAllowed\x12\x17\n\x07\x63ode_id\x18\x06 \x01(\x04R\x06\x63odeId\x12#\n\radmin_address\x18\x07 \x01(\tR\x0c\x61\x64minAddress\x12\'\n\x0fgranter_address\x18\x08 \x01(\tR\x0egranterAddress\x12\x42\n\x0c\x66unding_mode\x18\t \x01(\x0e\x32\x1f.injective.wasmx.v1.FundingModeR\x0b\x66undingMode:\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xe2\x01\n\x16\x42\x61tchStoreCodeProposal\x12\x14\n\x05title\x18\x01 \x01(\tR\x05title\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12G\n\tproposals\x18\x03 \x03(\x0b\x32#.cosmwasm.wasm.v1.StoreCodeProposalB\x04\xc8\xde\x1f\x00R\tproposals:G\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x1cwasmx/BatchStoreCodeProposal*G\n\x0b\x46undingMode\x12\x0f\n\x0bUnspecified\x10\x00\x12\x0e\n\nSelfFunded\x10\x01\x12\r\n\tGrantOnly\x10\x02\x12\x08\n\x04\x44ual\x10\x03\x42\xde\x01\n\x16\x63om.injective.wasmx.v1B\rProposalProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.proposal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\rProposalProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL'].fields_by_name['contract_registration_request']._loaded_options = None
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL'].fields_by_name['contract_registration_request']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL']._loaded_options = None
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*)wasmx/ContractRegistrationRequestProposal'
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL'].fields_by_name['contract_registration_requests']._loaded_options = None
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL'].fields_by_name['contract_registration_requests']._serialized_options = b'\310\336\037\000'
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL']._loaded_options = None
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*.wasmx/BatchContractRegistrationRequestProposal'
  _globals['_BATCHCONTRACTDEREGISTRATIONPROPOSAL']._loaded_options = None
  _globals['_BATCHCONTRACTDEREGISTRATIONPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*)wasmx/BatchContractDeregistrationProposal'
  _globals['_CONTRACTREGISTRATIONREQUEST']._loaded_options = None
  _globals['_CONTRACTREGISTRATIONREQUEST']._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_BATCHSTORECODEPROPOSAL'].fields_by_name['proposals']._loaded_options = None
  _globals['_BATCHSTORECODEPROPOSAL'].fields_by_name['proposals']._serialized_options = b'\310\336\037\000'
  _globals['_BATCHSTORECODEPROPOSAL']._loaded_options = None
  _globals['_BATCHSTORECODEPROPOSAL']._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\034wasmx/BatchStoreCodeProposal'
  _globals['_FUNDINGMODE']._serialized_start=1662
  _globals['_FUNDINGMODE']._serialized_end=1733
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_start=166
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_end=468
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_start=471
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_end=785
  _globals['_BATCHCONTRACTDEREGISTRATIONPROPOSAL']._serialized_start=788
  _globals['_BATCHCONTRACTDEREGISTRATIONPROPOSAL']._serialized_end=997
  _globals['_CONTRACTREGISTRATIONREQUEST']._serialized_start=1000
  _globals['_CONTRACTREGISTRATIONREQUEST']._serialized_end=1431
  _globals['_BATCHSTORECODEPROPOSAL']._serialized_start=1434
  _globals['_BATCHSTORECODEPROPOSAL']._serialized_end=1660
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, List, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_explorer_rpc_pb2 as exchange_explorer_pb,
    injective_explorer_rpc_pb2_grpc as exchange_explorer_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IndexerGrpcExplorerApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_explorer_grpc.InjectiveExplorerRPCStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_account_txs(
        self,
        address: str,
        before: Optional[int] = None,
        after: Optional[int] = None,
        message_type: Optional[str] = None,
        module: Optional[str] = None,
        from_number: Optional[int] = None,
        to_number: Optional[int] = None,
        status: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetAccountTxsRequest(
            address=address,
            before=before,
            after=after,
            limit=pagination.limit,
            skip=pagination.skip,
            type=message_type,
            module=module,
            from_number=from_number,
            to_number=to_number,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            status=status,
        )

        response = await self._execute_call(call=self._stub.GetAccountTxs, request=request)

        return response

    async def fetch_contract_txs(
        self,
        address: str,
        from_number: Optional[int] = None,
        to_number: Optional[int] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetAccountTxsRequest(
            address=address,
            limit=pagination.limit,
            skip=pagination.skip,
            from_number=from_number,
            to_number=to_number,
        )

        response = await self._execute_call(call=self._stub.GetContractTxs, request=request)

        return response

    async def fetch_contract_txs_v2(
        self,
        address: str,
        height: Optional[int] = None,
        token: Optional[str] = None,
        status: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetContractTxsV2Request(
            address=address,
            token=token,
        )
        if height is not None:
            request.height = height
        if pagination is not None:
            setattr(request, "from", pagination.start_time)
            request.to = pagination.end_time
            request.per_page = pagination.limit
        if status is not None:
            request.status = status

        response = await self._execute_call(call=self._stub.GetContractTxsV2, request=request)

        return response

    async def fetch_blocks(
        self,
        before: Optional[int] = None,
        after: Optional[int] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetBlocksRequest(
            before=before,
            after=after,
            limit=pagination.limit,
        )

        response = await self._execute_call(call=self._stub.GetBlocks, request=request)

        return response

    async def fetch_block(self, block_id: str) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetBlockRequest(id=block_id)

        response = await self._execute_call(call=self._stub.GetBlock, request=request)

        return response

    async def fetch_validators(self) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetValidatorsRequest()

        response = await self._execute_call(call=self._stub.GetValidators, request=request)

        return response

    async def fetch_validator(self, address: str) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetValidatorRequest(address=address)

        response = await self._execute_call(call=self._stub.GetValidator, request=request)

        return response

    async def fetch_validator_uptime(self, address: str) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetValidatorUptimeRequest(address=address)

        response = await self._execute_call(call=self._stub.GetValidatorUptime, request=request)

        return response

    async def fetch_txs(
        self,
        before: Optional[int] = None,
        after: Optional[int] = None,
        message_type: Optional[str] = None,
        module: Optional[str] = None,
        from_number: Optional[int] = None,
        to_number: Optional[int] = None,
        status: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetTxsRequest(
            before=before,
            after=after,
            limit=pagination.limit,
            skip=pagination.skip,
            type=message_type,
            module=module,
            from_number=from_number,
            to_number=to_number,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            status=status,
        )

        response = await self._execute_call(call=self._stub.GetTxs, request=request)

        return response

    async def fetch_tx_by_tx_hash(self, tx_hash: str) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetTxByTxHashRequest(hash=tx_hash)

        response = await self._execute_call(call=self._stub.GetTxByTxHash, request=request)

        return response

    async def fetch_peggy_deposit_txs(
        self,
        sender: Optional[str] = None,
        receiver: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetPeggyDepositTxsRequest(
            sender=sender,
            receiver=receiver,
            limit=pagination.limit,
            skip=pagination.skip,
        )

        response = await self._execute_call(call=self._stub.GetPeggyDepositTxs, request=request)

        return response

    async def fetch_peggy_withdrawal_txs(
        self,
        sender: Optional[str] = None,
        receiver: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetPeggyWithdrawalTxsRequest(
            sender=sender,
            receiver=receiver,
            limit=pagination.limit,
            skip=pagination.skip,
        )

        response = await self._execute_call(call=self._stub.GetPeggyWithdrawalTxs, request=request)

        return response

    async def fetch_ibc_transfer_txs(
        self,
        sender: Optional[str] = None,
        receiver: Optional[str] = None,
        src_channel: Optional[str] = None,
        src_port: Optional[str] = None,
        dest_channel: Optional[str] = None,
        dest_port: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetIBCTransferTxsRequest(
            sender=sender,
            receiver=receiver,
            src_channel=src_channel,
            src_port=src_port,
            dest_channel=dest_channel,
            dest_port=dest_port,
            limit=pagination.limit,
            skip=pagination.skip,
        )

        response = await self._execute_call(call=self._stub.GetIBCTransferTxs, request=request)

        return response

    async def fetch_wasm_codes(
        self,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetWasmCodesRequest(
            limit=pagination.limit,
            from_number=pagination.from_number,
            to_number=pagination.to_number,
        )

        response = await self._execute_call(call=self._stub.GetWasmCodes, request=request)

        return response

    async def fetch_wasm_code_by_id(
        self,
        code_id: int,
    ) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetWasmCodeByIDRequest(code_id=code_id)

        response = await self._execute_call(call=self._stub.GetWasmCodeByID, request=request)

        return response

    async def fetch_wasm_contracts(
        self,
        code_id: Optional[int] = None,
        assets_only: Optional[bool] = None,
        label: Optional[str] = None,
        token: Optional[str] = None,
        lookup: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetWasmContractsRequest(
            limit=pagination.limit,
            code_id=code_id,
            from_number=pagination.from_number,
            to_number=pagination.to_number,
            assets_only=assets_only,
            skip=pagination.skip,
            label=label,
            token=token,
            lookup=lookup,
        )

        response = await self._execute_call(call=self._stub.GetWasmContracts, request=request)

        return response

    async def fetch_wasm_contract_by_address(
        self,
        address: str,
    ) -> Dict[str, Any]:
        request = exchange_explorer_pb.GetWasmContractByAddressRequest(contract_address=address)

        response = await self._execute_call(call=self._stub.GetWasmContractByAddress, request=request)

        return response

    async def fetch_cw20_balance(
        self,
        address: str,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetCw20BalanceRequest(
            address=address,
            limit=pagination.limit,
        )

        response = await self._execute_call(call=self._stub.GetCw20Balance, request=request)

        return response

    async def fetch_relayers(
        self,
        market_ids: Optional[List[str]] = None,
    ) -> Dict[str, Any]:
        request = exchange_explorer_pb.RelayersRequest(market_i_ds=market_ids)

        response = await self._execute_call(call=self._stub.Relayers, request=request)

        return response

    async def fetch_bank_transfers(
        self,
        senders: Optional[List[str]] = None,
        recipients: Optional[List[str]] = None,
        is_community_pool_related: Optional[bool] = None,
        address: Optional[List[str]] = None,
        per_page: Optional[int] = None,
        token: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_explorer_pb.GetBankTransfersRequest(
            senders=senders,
            recipients=recipients,
            is_community_pool_related=is_community_pool_related,
            limit=pagination.limit,
            skip=pagination.skip,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            address=address,
            per_page=per_page,
            token=token,
        )

        response = await self._execute_call(call=self._stub.GetBankTransfers, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



from typing import Any, Callable, Dict

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.txfees.v1beta1 import query_pb2 as txfees_query_pb, query_pb2_grpc as txfees_query_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcTxfeesApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._query_stub = txfees_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = txfees_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._query_stub.Params, request=request)

        return response

    async def fetch_eip_base_fee(self) -> Dict[str, Any]:
        request = txfees_query_pb.QueryEipBaseFeeRequest()
        response = await self._execute_call(call=self._query_stub.GetEipBaseFee, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



class Denom:
    def __init__(
        self,
        description: str,
        base: int,
        quote: int,
        min_price_tick_size: float,
        min_quantity_tick_size: float,
        min_notional: float,
    ):
        self.description = description
        self.base = base
        self.quote = quote
        self.min_price_tick_size = min_price_tick_size
        self.min_quantity_tick_size = min_quantity_tick_size
        self.min_notional = min_notional



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.erc20.v1beta1 import query_pb2 as erc20_query_pb, query_pb2_grpc as erc20_query_grpc
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcERC20Api:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = erc20_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_erc20_params(self) -> Dict[str, Any]:
        request = erc20_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_all_token_pairs(
        self,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination_request = None
        if pagination is not None:
            pagination_request = pagination.create_pagination_request()
        request = erc20_query_pb.QueryAllTokenPairsRequest(
            pagination=pagination_request,
        )
        response = await self._execute_call(call=self._stub.AllTokenPairs, request=request)

        return response

    async def fetch_token_pair_by_denom(self, bank_denom: str) -> Dict[str, Any]:
        request = erc20_query_pb.QueryTokenPairByDenomRequest(bank_denom=bank_denom)
        response = await self._execute_call(call=self._stub.TokenPairByDenom, request=request)

        return response

    async def fetch_token_pair_by_erc20_address(self, erc20_address: str) -> Dict[str, Any]:
        request = erc20_query_pb.QueryTokenPairByERC20AddressRequest(erc20_address=erc20_address)
        response = await self._execute_call(call=self._stub.TokenPairByERC20Address, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from pyinjective.proto.ibc.core.channel.v1 import upgrade_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_upgrade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cibc/core/channel/v1/tx.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1fibc/core/client/v1/client.proto\x1a!ibc/core/channel/v1/channel.proto\x1a!ibc/core/channel/v1/upgrade.proto\"\x94\x01\n\x12MsgChannelOpenInit\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12<\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00R\x07\x63hannel\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"[\n\x1aMsgChannelOpenInitResponse\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version:\x04\x88\xa0\x1f\x00\"\xde\x02\n\x11MsgChannelOpenTry\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x32\n\x13previous_channel_id\x18\x02 \x01(\tB\x02\x18\x01R\x11previousChannelId\x12<\n\x07\x63hannel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00R\x07\x63hannel\x12\x31\n\x14\x63ounterparty_version\x18\x04 \x01(\tR\x13\x63ounterpartyVersion\x12\x1d\n\nproof_init\x18\x05 \x01(\x0cR\tproofInit\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"Z\n\x19MsgChannelOpenTryResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId:\x04\x88\xa0\x1f\x00\"\xc1\x02\n\x11MsgChannelOpenAck\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x36\n\x17\x63ounterparty_channel_id\x18\x03 \x01(\tR\x15\x63ounterpartyChannelId\x12\x31\n\x14\x63ounterparty_version\x18\x04 \x01(\tR\x13\x63ounterpartyVersion\x12\x1b\n\tproof_try\x18\x05 \x01(\x0cR\x08proofTry\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1b\n\x19MsgChannelOpenAckResponse\"\xda\x01\n\x15MsgChannelOpenConfirm\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1b\n\tproof_ack\x18\x03 \x01(\x0cR\x08proofAck\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgChannelOpenConfirmResponse\"v\n\x13MsgChannelCloseInit\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x16\n\x06signer\x18\x03 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1d\n\x1bMsgChannelCloseInitResponse\"\xa1\x02\n\x16MsgChannelCloseConfirm\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1d\n\nproof_init\x18\x03 \x01(\x0cR\tproofInit\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x06 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\" \n\x1eMsgChannelCloseConfirmResponse\"\xe3\x01\n\rMsgRecvPacket\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12)\n\x10proof_commitment\x18\x02 \x01(\x0cR\x0fproofCommitment\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"^\n\x15MsgRecvPacketResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\x8e\x02\n\nMsgTimeout\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12)\n\x10proof_unreceived\x18\x02 \x01(\x0cR\x0fproofUnreceived\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12,\n\x12next_sequence_recv\x18\x04 \x01(\x04R\x10nextSequenceRecv\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"[\n\x12MsgTimeoutResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xfa\x02\n\x11MsgTimeoutOnClose\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12)\n\x10proof_unreceived\x18\x02 \x01(\x0cR\x0fproofUnreceived\x12\x1f\n\x0bproof_close\x18\x03 \x01(\x0cR\nproofClose\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12,\n\x12next_sequence_recv\x18\x05 \x01(\x04R\x10nextSequenceRecv\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x07 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"b\n\x19MsgTimeoutOnCloseResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\x88\x02\n\x12MsgAcknowledgement\x12\x39\n\x06packet\x18\x01 \x01(\x0b\x32\x1b.ibc.core.channel.v1.PacketB\x04\xc8\xde\x1f\x00R\x06packet\x12(\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0cR\x0f\x61\x63knowledgement\x12\x1f\n\x0bproof_acked\x18\x03 \x01(\x0cR\nproofAcked\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x05 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"c\n\x1aMsgAcknowledgementResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xba\x01\n\x15MsgChannelUpgradeInit\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12@\n\x06\x66ields\x18\x03 \x01(\x0b\x32\".ibc.core.channel.v1.UpgradeFieldsB\x04\xc8\xde\x1f\x00R\x06\x66ields\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x8e\x01\n\x1dMsgChannelUpgradeInitResponse\x12<\n\x07upgrade\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x07upgrade\x12)\n\x10upgrade_sequence\x18\x02 \x01(\x04R\x0fupgradeSequence:\x04\x88\xa0\x1f\x00\"\xfd\x03\n\x14MsgChannelUpgradeTry\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12G\n proposed_upgrade_connection_hops\x18\x03 \x03(\tR\x1dproposedUpgradeConnectionHops\x12h\n\x1b\x63ounterparty_upgrade_fields\x18\x04 \x01(\x0b\x32\".ibc.core.channel.v1.UpgradeFieldsB\x04\xc8\xde\x1f\x00R\x19\x63ounterpartyUpgradeFields\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x05 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence\x12#\n\rproof_channel\x18\x06 \x01(\x0cR\x0cproofChannel\x12#\n\rproof_upgrade\x18\x07 \x01(\x0cR\x0cproofUpgrade\x12\x43\n\x0cproof_height\x18\x08 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\t \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\xce\x01\n\x1cMsgChannelUpgradeTryResponse\x12<\n\x07upgrade\x18\x01 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x07upgrade\x12)\n\x10upgrade_sequence\x18\x02 \x01(\x04R\x0fupgradeSequence\x12?\n\x06result\x18\x03 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xdd\x02\n\x14MsgChannelUpgradeAck\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12U\n\x14\x63ounterparty_upgrade\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x13\x63ounterpartyUpgrade\x12#\n\rproof_channel\x18\x04 \x01(\x0cR\x0cproofChannel\x12#\n\rproof_upgrade\x18\x05 \x01(\x0cR\x0cproofUpgrade\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"e\n\x1cMsgChannelUpgradeAckResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\xbb\x03\n\x18MsgChannelUpgradeConfirm\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12X\n\x1a\x63ounterparty_channel_state\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.StateR\x18\x63ounterpartyChannelState\x12U\n\x14\x63ounterparty_upgrade\x18\x04 \x01(\x0b\x32\x1c.ibc.core.channel.v1.UpgradeB\x04\xc8\xde\x1f\x00R\x13\x63ounterpartyUpgrade\x12#\n\rproof_channel\x18\x05 \x01(\x0cR\x0cproofChannel\x12#\n\rproof_upgrade\x18\x06 \x01(\x0cR\x0cproofUpgrade\x12\x43\n\x0cproof_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x08 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"i\n MsgChannelUpgradeConfirmResponse\x12?\n\x06result\x18\x01 \x01(\x0e\x32\'.ibc.core.channel.v1.ResponseResultTypeR\x06result:\x04\x88\xa0\x1f\x00\"\x80\x03\n\x15MsgChannelUpgradeOpen\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12X\n\x1a\x63ounterparty_channel_state\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.StateR\x18\x63ounterpartyChannelState\x12\x42\n\x1d\x63ounterparty_upgrade_sequence\x18\x04 \x01(\x04R\x1b\x63ounterpartyUpgradeSequence\x12#\n\rproof_channel\x18\x05 \x01(\x0cR\x0cproofChannel\x12\x43\n\x0cproof_height\x18\x06 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x07 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x1f\n\x1dMsgChannelUpgradeOpenResponse\"\xbc\x02\n\x18MsgChannelUpgradeTimeout\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12U\n\x14\x63ounterparty_channel\x18\x03 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelB\x04\xc8\xde\x1f\x00R\x13\x63ounterpartyChannel\x12#\n\rproof_channel\x18\x04 \x01(\x0cR\x0cproofChannel\x12\x43\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\"\n MsgChannelUpgradeTimeoutResponse\"\xbd\x02\n\x17MsgChannelUpgradeCancel\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12L\n\rerror_receipt\x18\x03 \x01(\x0b\x32!.ibc.core.channel.v1.ErrorReceiptB\x04\xc8\xde\x1f\x00R\x0c\x65rrorReceipt\x12.\n\x13proof_error_receipt\x18\x04 \x01(\x0cR\x11proofErrorReceipt\x12\x43\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12\x16\n\x06signer\x18\x06 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"!\n\x1fMsgChannelUpgradeCancelResponse\"~\n\x0fMsgUpdateParams\x12\x1c\n\tauthority\x18\x01 \x01(\tR\tauthority\x12\x39\n\x06params\x18\x02 \x01(\x0b\x32\x1b.ibc.core.channel.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:\x12\x88\xa0\x1f\x00\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse\"\x91\x01\n\x18MsgPruneAcknowledgements\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x14\n\x05limit\x18\x03 \x01(\x04R\x05limit\x12\x16\n\x06signer\x18\x04 \x01(\tR\x06signer:\x0f\x88\xa0\x1f\x00\x82\xe7\xb0*\x06signer\"\x94\x01\n MsgPruneAcknowledgementsResponse\x12\x34\n\x16total_pruned_sequences\x18\x01 \x01(\x04R\x14totalPrunedSequences\x12:\n\x19total_remaining_sequences\x18\x02 \x01(\x04R\x17totalRemainingSequences*\xd8\x01\n\x12ResponseResultType\x12\x35\n RESPONSE_RESULT_TYPE_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12\'\n\x19RESPONSE_RESULT_TYPE_NOOP\x10\x01\x1a\x08\x8a\x9d \x04NOOP\x12-\n\x1cRESPONSE_RESULT_TYPE_SUCCESS\x10\x02\x1a\x0b\x8a\x9d \x07SUCCESS\x12-\n\x1cRESPONSE_RESULT_TYPE_FAILURE\x10\x03\x1a\x0b\x8a\x9d \x07\x46\x41ILURE\x1a\x04\x88\xa3\x1e\x00\x32\xec\x10\n\x03Msg\x12k\n\x0f\x43hannelOpenInit\x12\'.ibc.core.channel.v1.MsgChannelOpenInit\x1a/.ibc.core.channel.v1.MsgChannelOpenInitResponse\x12h\n\x0e\x43hannelOpenTry\x12&.ibc.core.channel.v1.MsgChannelOpenTry\x1a..ibc.core.channel.v1.MsgChannelOpenTryResponse\x12h\n\x0e\x43hannelOpenAck\x12&.ibc.core.channel.v1.MsgChannelOpenAck\x1a..ibc.core.channel.v1.MsgChannelOpenAckResponse\x12t\n\x12\x43hannelOpenConfirm\x12*.ibc.core.channel.v1.MsgChannelOpenConfirm\x1a\x32.ibc.core.channel.v1.MsgChannelOpenConfirmResponse\x12n\n\x10\x43hannelCloseInit\x12(.ibc.core.channel.v1.MsgChannelCloseInit\x1a\x30.ibc.core.channel.v1.MsgChannelCloseInitResponse\x12w\n\x13\x43hannelCloseConfirm\x12+.ibc.core.channel.v1.MsgChannelCloseConfirm\x1a\x33.ibc.core.channel.v1.MsgChannelCloseConfirmResponse\x12\\\n\nRecvPacket\x12\".ibc.core.channel.v1.MsgRecvPacket\x1a*.ibc.core.channel.v1.MsgRecvPacketResponse\x12S\n\x07Timeout\x12\x1f.ibc.core.channel.v1.MsgTimeout\x1a\'.ibc.core.channel.v1.MsgTimeoutResponse\x12h\n\x0eTimeoutOnClose\x12&.ibc.core.channel.v1.MsgTimeoutOnClose\x1a..ibc.core.channel.v1.MsgTimeoutOnCloseResponse\x12k\n\x0f\x41\x63knowledgement\x12\'.ibc.core.channel.v1.MsgAcknowledgement\x1a/.ibc.core.channel.v1.MsgAcknowledgementResponse\x12t\n\x12\x43hannelUpgradeInit\x12*.ibc.core.channel.v1.MsgChannelUpgradeInit\x1a\x32.ibc.core.channel.v1.MsgChannelUpgradeInitResponse\x12q\n\x11\x43hannelUpgradeTry\x12).ibc.core.channel.v1.MsgChannelUpgradeTry\x1a\x31.ibc.core.channel.v1.MsgChannelUpgradeTryResponse\x12q\n\x11\x43hannelUpgradeAck\x12).ibc.core.channel.v1.MsgChannelUpgradeAck\x1a\x31.ibc.core.channel.v1.MsgChannelUpgradeAckResponse\x12}\n\x15\x43hannelUpgradeConfirm\x12-.ibc.core.channel.v1.MsgChannelUpgradeConfirm\x1a\x35.ibc.core.channel.v1.MsgChannelUpgradeConfirmResponse\x12t\n\x12\x43hannelUpgradeOpen\x12*.ibc.core.channel.v1.MsgChannelUpgradeOpen\x1a\x32.ibc.core.channel.v1.MsgChannelUpgradeOpenResponse\x12}\n\x15\x43hannelUpgradeTimeout\x12-.ibc.core.channel.v1.MsgChannelUpgradeTimeout\x1a\x35.ibc.core.channel.v1.MsgChannelUpgradeTimeoutResponse\x12z\n\x14\x43hannelUpgradeCancel\x12,.ibc.core.channel.v1.MsgChannelUpgradeCancel\x1a\x34.ibc.core.channel.v1.MsgChannelUpgradeCancelResponse\x12i\n\x13UpdateChannelParams\x12$.ibc.core.channel.v1.MsgUpdateParams\x1a,.ibc.core.channel.v1.MsgUpdateParamsResponse\x12}\n\x15PruneAcknowledgements\x12-.ibc.core.channel.v1.MsgPruneAcknowledgements\x1a\x35.ibc.core.channel.v1.MsgPruneAcknowledgementsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xcc\x01\n\x17\x63om.ibc.core.channel.v1B\x07TxProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\007TxProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_RESPONSERESULTTYPE']._loaded_options = None
  _globals['_RESPONSERESULTTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_NOOP"]._serialized_options = b'\212\235 \004NOOP'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_SUCCESS"]._serialized_options = b'\212\235 \007SUCCESS'
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_FAILURE"]._loaded_options = None
  _globals['_RESPONSERESULTTYPE'].values_by_name["RESPONSE_RESULT_TYPE_FAILURE"]._serialized_options = b'\212\235 \007FAILURE'
  _globals['_MSGCHANNELOPENINIT'].fields_by_name['channel']._loaded_options = None
  _globals['_MSGCHANNELOPENINIT'].fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENINIT']._loaded_options = None
  _globals['_MSGCHANNELOPENINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELOPENINITRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELOPENINITRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['previous_channel_id']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['previous_channel_id']._serialized_options = b'\030\001'
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['channel']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['channel']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENTRY']._loaded_options = None
  _globals['_MSGCHANNELOPENTRY']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELOPENTRYRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELOPENTRYRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELOPENACK'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELOPENACK'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENACK']._loaded_options = None
  _globals['_MSGCHANNELOPENACK']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELOPENCONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELOPENCONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELOPENCONFIRM']._loaded_options = None
  _globals['_MSGCHANNELOPENCONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELCLOSEINIT']._loaded_options = None
  _globals['_MSGCHANNELCLOSEINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELCLOSECONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELCLOSECONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELCLOSECONFIRM']._loaded_options = None
  _globals['_MSGCHANNELCLOSECONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGRECVPACKET'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGRECVPACKET'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGRECVPACKET'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGRECVPACKET'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGRECVPACKET']._loaded_options = None
  _globals['_MSGRECVPACKET']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGRECVPACKETRESPONSE']._loaded_options = None
  _globals['_MSGRECVPACKETRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGTIMEOUT'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGTIMEOUT'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUT'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGTIMEOUT'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUT']._loaded_options = None
  _globals['_MSGTIMEOUT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGTIMEOUTRESPONSE']._loaded_options = None
  _globals['_MSGTIMEOUTRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGTIMEOUTONCLOSE']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSE']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._loaded_options = None
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['packet']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['packet']._serialized_options = b'\310\336\037\000'
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENT'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGACKNOWLEDGEMENT']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._loaded_options = None
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADEINIT'].fields_by_name['fields']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINIT'].fields_by_name['fields']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEINIT']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINIT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADEINITRESPONSE'].fields_by_name['upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINITRESPONSE'].fields_by_name['upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['counterparty_upgrade_fields']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['counterparty_upgrade_fields']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRY'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETRY']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRY']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADETRYRESPONSE'].fields_by_name['upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRYRESPONSE'].fields_by_name['upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['counterparty_upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['counterparty_upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACK'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEACK']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACK']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['counterparty_upgrade']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['counterparty_upgrade']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRM'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECONFIRM']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRM']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._serialized_options = b'\210\240\037\000'
  _globals['_MSGCHANNELUPGRADEOPEN'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEOPEN'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADEOPEN']._loaded_options = None
  _globals['_MSGCHANNELUPGRADEOPEN']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['counterparty_channel']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['counterparty_channel']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETIMEOUT'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADETIMEOUT']._loaded_options = None
  _globals['_MSGCHANNELUPGRADETIMEOUT']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['error_receipt']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['error_receipt']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['proof_height']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECANCEL'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCHANNELUPGRADECANCEL']._loaded_options = None
  _globals['_MSGCHANNELUPGRADECANCEL']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\210\240\037\000\202\347\260*\tauthority'
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._loaded_options = None
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._serialized_options = b'\210\240\037\000\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_RESPONSERESULTTYPE']._serialized_start=7165
  _globals['_RESPONSERESULTTYPE']._serialized_end=7381
  _globals['_MSGCHANNELOPENINIT']._serialized_start=204
  _globals['_MSGCHANNELOPENINIT']._serialized_end=352
  _globals['_MSGCHANNELOPENINITRESPONSE']._serialized_start=354
  _globals['_MSGCHANNELOPENINITRESPONSE']._serialized_end=445
  _globals['_MSGCHANNELOPENTRY']._serialized_start=448
  _globals['_MSGCHANNELOPENTRY']._serialized_end=798
  _globals['_MSGCHANNELOPENTRYRESPONSE']._serialized_start=800
  _globals['_MSGCHANNELOPENTRYRESPONSE']._serialized_end=890
  _globals['_MSGCHANNELOPENACK']._serialized_start=893
  _globals['_MSGCHANNELOPENACK']._serialized_end=1214
  _globals['_MSGCHANNELOPENACKRESPONSE']._serialized_start=1216
  _globals['_MSGCHANNELOPENACKRESPONSE']._serialized_end=1243
  _globals['_MSGCHANNELOPENCONFIRM']._serialized_start=1246
  _globals['_MSGCHANNELOPENCONFIRM']._serialized_end=1464
  _globals['_MSGCHANNELOPENCONFIRMRESPONSE']._serialized_start=1466
  _globals['_MSGCHANNELOPENCONFIRMRESPONSE']._serialized_end=1497
  _globals['_MSGCHANNELCLOSEINIT']._serialized_start=1499
  _globals['_MSGCHANNELCLOSEINIT']._serialized_end=1617
  _globals['_MSGCHANNELCLOSEINITRESPONSE']._serialized_start=1619
  _globals['_MSGCHANNELCLOSEINITRESPONSE']._serialized_end=1648
  _globals['_MSGCHANNELCLOSECONFIRM']._serialized_start=1651
  _globals['_MSGCHANNELCLOSECONFIRM']._serialized_end=1940
  _globals['_MSGCHANNELCLOSECONFIRMRESPONSE']._serialized_start=1942
  _globals['_MSGCHANNELCLOSECONFIRMRESPONSE']._serialized_end=1974
  _globals['_MSGRECVPACKET']._serialized_start=1977
  _globals['_MSGRECVPACKET']._serialized_end=2204
  _globals['_MSGRECVPACKETRESPONSE']._serialized_start=2206
  _globals['_MSGRECVPACKETRESPONSE']._serialized_end=2300
  _globals['_MSGTIMEOUT']._serialized_start=2303
  _globals['_MSGTIMEOUT']._serialized_end=2573
  _globals['_MSGTIMEOUTRESPONSE']._serialized_start=2575
  _globals['_MSGTIMEOUTRESPONSE']._serialized_end=2666
  _globals['_MSGTIMEOUTONCLOSE']._serialized_start=2669
  _globals['_MSGTIMEOUTONCLOSE']._serialized_end=3047
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._serialized_start=3049
  _globals['_MSGTIMEOUTONCLOSERESPONSE']._serialized_end=3147
  _globals['_MSGACKNOWLEDGEMENT']._serialized_start=3150
  _globals['_MSGACKNOWLEDGEMENT']._serialized_end=3414
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._serialized_start=3416
  _globals['_MSGACKNOWLEDGEMENTRESPONSE']._serialized_end=3515
  _globals['_MSGCHANNELUPGRADEINIT']._serialized_start=3518
  _globals['_MSGCHANNELUPGRADEINIT']._serialized_end=3704
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._serialized_start=3707
  _globals['_MSGCHANNELUPGRADEINITRESPONSE']._serialized_end=3849
  _globals['_MSGCHANNELUPGRADETRY']._serialized_start=3852
  _globals['_MSGCHANNELUPGRADETRY']._serialized_end=4361
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._serialized_start=4364
  _globals['_MSGCHANNELUPGRADETRYRESPONSE']._serialized_end=4570
  _globals['_MSGCHANNELUPGRADEACK']._serialized_start=4573
  _globals['_MSGCHANNELUPGRADEACK']._serialized_end=4922
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._serialized_start=4924
  _globals['_MSGCHANNELUPGRADEACKRESPONSE']._serialized_end=5025
  _globals['_MSGCHANNELUPGRADECONFIRM']._serialized_start=5028
  _globals['_MSGCHANNELUPGRADECONFIRM']._serialized_end=5471
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._serialized_start=5473
  _globals['_MSGCHANNELUPGRADECONFIRMRESPONSE']._serialized_end=5578
  _globals['_MSGCHANNELUPGRADEOPEN']._serialized_start=5581
  _globals['_MSGCHANNELUPGRADEOPEN']._serialized_end=5965
  _globals['_MSGCHANNELUPGRADEOPENRESPONSE']._serialized_start=5967
  _globals['_MSGCHANNELUPGRADEOPENRESPONSE']._serialized_end=5998
  _globals['_MSGCHANNELUPGRADETIMEOUT']._serialized_start=6001
  _globals['_MSGCHANNELUPGRADETIMEOUT']._serialized_end=6317
  _globals['_MSGCHANNELUPGRADETIMEOUTRESPONSE']._serialized_start=6319
  _globals['_MSGCHANNELUPGRADETIMEOUTRESPONSE']._serialized_end=6353
  _globals['_MSGCHANNELUPGRADECANCEL']._serialized_start=6356
  _globals['_MSGCHANNELUPGRADECANCEL']._serialized_end=6673
  _globals['_MSGCHANNELUPGRADECANCELRESPONSE']._serialized_start=6675
  _globals['_MSGCHANNELUPGRADECANCELRESPONSE']._serialized_end=6708
  _globals['_MSGUPDATEPARAMS']._serialized_start=6710
  _globals['_MSGUPDATEPARAMS']._serialized_end=6836
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=6838
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=6863
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._serialized_start=6866
  _globals['_MSGPRUNEACKNOWLEDGEMENTS']._serialized_end=7011
  _globals['_MSGPRUNEACKNOWLEDGEMENTSRESPONSE']._serialized_start=7014
  _globals['_MSGPRUNEACKNOWLEDGEMENTSRESPONSE']._serialized_end=7162
  _globals['_MSG']._serialized_start=7384
  _globals['_MSG']._serialized_end=9540
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/insurance/v1beta1/tx.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a+injective/insurance/v1beta1/insurance.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x11\x61mino/amino.proto\"\x90\x03\n\x16MsgCreateInsuranceFund\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x16\n\x06ticker\x18\x02 \x01(\tR\x06ticker\x12\x1f\n\x0bquote_denom\x18\x03 \x01(\tR\nquoteDenom\x12\x1f\n\x0boracle_base\x18\x04 \x01(\tR\noracleBase\x12!\n\x0coracle_quote\x18\x05 \x01(\tR\x0boracleQuote\x12\x45\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12\x16\n\x06\x65xpiry\x18\x07 \x01(\x03R\x06\x65xpiry\x12H\n\x0finitial_deposit\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x0einitialDeposit:8\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0* insurance/MsgCreateInsuranceFund\" \n\x1eMsgCreateInsuranceFundResponse\"\xb0\x01\n\rMsgUnderwrite\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x39\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x07\x64\x65posit:/\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x17insurance/MsgUnderwrite\"\x17\n\x15MsgUnderwriteResponse\"\xbc\x01\n\x14MsgRequestRedemption\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x37\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount:6\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1einsurance/MsgRequestRedemption\"\x1e\n\x1cMsgRequestRedemptionResponse\"\xba\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x41\n\x06params\x18\x02 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:,\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x19insurance/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xfc\x03\n\x03Msg\x12\x87\x01\n\x13\x43reateInsuranceFund\x12\x33.injective.insurance.v1beta1.MsgCreateInsuranceFund\x1a;.injective.insurance.v1beta1.MsgCreateInsuranceFundResponse\x12l\n\nUnderwrite\x12*.injective.insurance.v1beta1.MsgUnderwrite\x1a\x32.injective.insurance.v1beta1.MsgUnderwriteResponse\x12\x81\x01\n\x11RequestRedemption\x12\x31.injective.insurance.v1beta1.MsgRequestRedemption\x1a\x39.injective.insurance.v1beta1.MsgRequestRedemptionResponse\x12r\n\x0cUpdateParams\x12,.injective.insurance.v1beta1.MsgUpdateParams\x1a\x34.injective.insurance.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x89\x02\n\x1f\x63om.injective.insurance.v1beta1B\x07TxProtoP\x01ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\xa2\x02\x03IIX\xaa\x02\x1bInjective.Insurance.V1beta1\xca\x02\x1bInjective\\Insurance\\V1beta1\xe2\x02\'Injective\\Insurance\\V1beta1\\GPBMetadata\xea\x02\x1dInjective::Insurance::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.injective.insurance.v1beta1B\007TxProtoP\001ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types\242\002\003IIX\252\002\033Injective.Insurance.V1beta1\312\002\033Injective\\Insurance\\V1beta1\342\002\'Injective\\Insurance\\V1beta1\\GPBMetadata\352\002\035Injective::Insurance::V1beta1'
  _globals['_MSGCREATEINSURANCEFUND'].fields_by_name['initial_deposit']._loaded_options = None
  _globals['_MSGCREATEINSURANCEFUND'].fields_by_name['initial_deposit']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEINSURANCEFUND']._loaded_options = None
  _globals['_MSGCREATEINSURANCEFUND']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260* insurance/MsgCreateInsuranceFund'
  _globals['_MSGUNDERWRITE'].fields_by_name['deposit']._loaded_options = None
  _globals['_MSGUNDERWRITE'].fields_by_name['deposit']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUNDERWRITE']._loaded_options = None
  _globals['_MSGUNDERWRITE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\027insurance/MsgUnderwrite'
  _globals['_MSGREQUESTREDEMPTION'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGREQUESTREDEMPTION'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_MSGREQUESTREDEMPTION']._loaded_options = None
  _globals['_MSGREQUESTREDEMPTION']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\036insurance/MsgRequestRedemption'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\031insurance/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEINSURANCEFUND']._serialized_start=279
  _globals['_MSGCREATEINSURANCEFUND']._serialized_end=679
  _globals['_MSGCREATEINSURANCEFUNDRESPONSE']._serialized_start=681
  _globals['_MSGCREATEINSURANCEFUNDRESPONSE']._serialized_end=713
  _globals['_MSGUNDERWRITE']._serialized_start=716
  _globals['_MSGUNDERWRITE']._serialized_end=892
  _globals['_MSGUNDERWRITERESPONSE']._serialized_start=894
  _globals['_MSGUNDERWRITERESPONSE']._serialized_end=917
  _globals['_MSGREQUESTREDEMPTION']._serialized_start=920
  _globals['_MSGREQUESTREDEMPTION']._serialized_end=1108
  _globals['_MSGREQUESTREDEMPTIONRESPONSE']._serialized_start=1110
  _globals['_MSGREQUESTREDEMPTIONRESPONSE']._serialized_end=1140
  _globals['_MSGUPDATEPARAMS']._serialized_start=1143
  _globals['_MSGUPDATEPARAMS']._serialized_end=1329
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1331
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1356
  _globals['_MSG']._serialized_start=1359
  _globals['_MSG']._serialized_end=1867
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from pyinjective.proto.ibc.applications.fee.v1 import genesis_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_genesis__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ibc/applications/fee/v1/query.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a%ibc/applications/fee/v1/genesis.proto\x1a!ibc/core/channel/v1/channel.proto\"\x8c\x01\n\x1fQueryIncentivizedPacketsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\x12!\n\x0cquery_height\x18\x02 \x01(\x04R\x0bqueryHeight\"\xd3\x01\n QueryIncentivizedPacketsResponse\x12\x66\n\x14incentivized_packets\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00R\x13incentivizedPackets\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x85\x01\n\x1eQueryIncentivizedPacketRequest\x12@\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00R\x08packetId\x12!\n\x0cquery_height\x18\x02 \x01(\x04R\x0bqueryHeight\"\x87\x01\n\x1fQueryIncentivizedPacketResponse\x12\x64\n\x13incentivized_packet\x18\x01 \x01(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00R\x12incentivizedPacket\"\xce\x01\n)QueryIncentivizedPacketsForChannelRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\x12\x17\n\x07port_id\x18\x02 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x03 \x01(\tR\tchannelId\x12!\n\x0cquery_height\x18\x04 \x01(\x04R\x0bqueryHeight\"\xd7\x01\n*QueryIncentivizedPacketsForChannelResponse\x12`\n\x14incentivized_packets\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesR\x13incentivizedPackets\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"]\n\x19QueryTotalRecvFeesRequest\x12@\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00R\x08packetId\"\x86\x01\n\x1aQueryTotalRecvFeesResponse\x12h\n\trecv_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x08recvFees\"\\\n\x18QueryTotalAckFeesRequest\x12@\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00R\x08packetId\"\x83\x01\n\x19QueryTotalAckFeesResponse\x12\x66\n\x08\x61\x63k_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x07\x61\x63kFees\"`\n\x1cQueryTotalTimeoutFeesRequest\x12@\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00R\x08packetId\"\x8f\x01\n\x1dQueryTotalTimeoutFeesResponse\x12n\n\x0ctimeout_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x0btimeoutFees\"L\n\x11QueryPayeeRequest\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x18\n\x07relayer\x18\x02 \x01(\tR\x07relayer\"9\n\x12QueryPayeeResponse\x12#\n\rpayee_address\x18\x01 \x01(\tR\x0cpayeeAddress\"X\n\x1dQueryCounterpartyPayeeRequest\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x18\n\x07relayer\x18\x02 \x01(\tR\x07relayer\"O\n\x1eQueryCounterpartyPayeeResponse\x12-\n\x12\x63ounterparty_payee\x18\x01 \x01(\tR\x11\x63ounterpartyPayee\"\x8b\x01\n\x1eQueryFeeEnabledChannelsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\x12!\n\x0cquery_height\x18\x02 \x01(\x04R\x0bqueryHeight\"\xce\x01\n\x1fQueryFeeEnabledChannelsResponse\x12\x62\n\x14\x66\x65\x65_enabled_channels\x18\x01 \x03(\x0b\x32*.ibc.applications.fee.v1.FeeEnabledChannelB\x04\xc8\xde\x1f\x00R\x12\x66\x65\x65\x45nabledChannels\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"W\n\x1dQueryFeeEnabledChannelRequest\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"A\n\x1eQueryFeeEnabledChannelResponse\x12\x1f\n\x0b\x66\x65\x65_enabled\x18\x01 \x01(\x08R\nfeeEnabled2\xe6\x11\n\x05Query\x12\xb9\x01\n\x13IncentivizedPackets\x12\x38.ibc.applications.fee.v1.QueryIncentivizedPacketsRequest\x1a\x39.ibc.applications.fee.v1.QueryIncentivizedPacketsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/ibc/apps/fee/v1/incentivized_packets\x12\x8f\x02\n\x12IncentivizedPacket\x12\x37.ibc.applications.fee.v1.QueryIncentivizedPacketRequest\x1a\x38.ibc.applications.fee.v1.QueryIncentivizedPacketResponse\"\x85\x01\x82\xd3\xe4\x93\x02\x7f\x12}/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/incentivized_packet\x12\xfd\x01\n\x1dIncentivizedPacketsForChannel\x12\x42.ibc.applications.fee.v1.QueryIncentivizedPacketsForChannelRequest\x1a\x43.ibc.applications.fee.v1.QueryIncentivizedPacketsForChannelResponse\"S\x82\xd3\xe4\x93\x02M\x12K/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/incentivized_packets\x12\xfc\x01\n\rTotalRecvFees\x12\x32.ibc.applications.fee.v1.QueryTotalRecvFeesRequest\x1a\x33.ibc.applications.fee.v1.QueryTotalRecvFeesResponse\"\x81\x01\x82\xd3\xe4\x93\x02{\x12y/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_recv_fees\x12\xf8\x01\n\x0cTotalAckFees\x12\x31.ibc.applications.fee.v1.QueryTotalAckFeesRequest\x1a\x32.ibc.applications.fee.v1.QueryTotalAckFeesResponse\"\x80\x01\x82\xd3\xe4\x93\x02z\x12x/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_ack_fees\x12\x88\x02\n\x10TotalTimeoutFees\x12\x35.ibc.applications.fee.v1.QueryTotalTimeoutFeesRequest\x1a\x36.ibc.applications.fee.v1.QueryTotalTimeoutFeesResponse\"\x84\x01\x82\xd3\xe4\x93\x02~\x12|/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_timeout_fees\x12\xa9\x01\n\x05Payee\x12*.ibc.applications.fee.v1.QueryPayeeRequest\x1a+.ibc.applications.fee.v1.QueryPayeeResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/payee\x12\xda\x01\n\x11\x43ounterpartyPayee\x12\x36.ibc.applications.fee.v1.QueryCounterpartyPayeeRequest\x1a\x37.ibc.applications.fee.v1.QueryCounterpartyPayeeResponse\"T\x82\xd3\xe4\x93\x02N\x12L/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/counterparty_payee\x12\xad\x01\n\x12\x46\x65\x65\x45nabledChannels\x12\x37.ibc.applications.fee.v1.QueryFeeEnabledChannelsRequest\x1a\x38.ibc.applications.fee.v1.QueryFeeEnabledChannelsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/fee/v1/fee_enabled\x12\xd0\x01\n\x11\x46\x65\x65\x45nabledChannel\x12\x36.ibc.applications.fee.v1.QueryFeeEnabledChannelRequest\x1a\x37.ibc.applications.fee.v1.QueryFeeEnabledChannelResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/fee_enabledB\xdf\x01\n\x1b\x63om.ibc.applications.fee.v1B\nQueryProtoP\x01Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\xa2\x02\x03IAF\xaa\x02\x17Ibc.Applications.Fee.V1\xca\x02\x17Ibc\\Applications\\Fee\\V1\xe2\x02#Ibc\\Applications\\Fee\\V1\\GPBMetadata\xea\x02\x1aIbc::Applications::Fee::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.ibc.applications.fee.v1B\nQueryProtoP\001Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\242\002\003IAF\252\002\027Ibc.Applications.Fee.V1\312\002\027Ibc\\Applications\\Fee\\V1\342\002#Ibc\\Applications\\Fee\\V1\\GPBMetadata\352\002\032Ibc::Applications::Fee::V1'
  _globals['_QUERYINCENTIVIZEDPACKETSRESPONSE'].fields_by_name['incentivized_packets']._loaded_options = None
  _globals['_QUERYINCENTIVIZEDPACKETSRESPONSE'].fields_by_name['incentivized_packets']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYINCENTIVIZEDPACKETREQUEST'].fields_by_name['packet_id']._loaded_options = None
  _globals['_QUERYINCENTIVIZEDPACKETREQUEST'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYINCENTIVIZEDPACKETRESPONSE'].fields_by_name['incentivized_packet']._loaded_options = None
  _globals['_QUERYINCENTIVIZEDPACKETRESPONSE'].fields_by_name['incentivized_packet']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYTOTALRECVFEESREQUEST'].fields_by_name['packet_id']._loaded_options = None
  _globals['_QUERYTOTALRECVFEESREQUEST'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYTOTALRECVFEESRESPONSE'].fields_by_name['recv_fees']._loaded_options = None
  _globals['_QUERYTOTALRECVFEESRESPONSE'].fields_by_name['recv_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYTOTALACKFEESREQUEST'].fields_by_name['packet_id']._loaded_options = None
  _globals['_QUERYTOTALACKFEESREQUEST'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYTOTALACKFEESRESPONSE'].fields_by_name['ack_fees']._loaded_options = None
  _globals['_QUERYTOTALACKFEESRESPONSE'].fields_by_name['ack_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYTOTALTIMEOUTFEESREQUEST'].fields_by_name['packet_id']._loaded_options = None
  _globals['_QUERYTOTALTIMEOUTFEESREQUEST'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYTOTALTIMEOUTFEESRESPONSE'].fields_by_name['timeout_fees']._loaded_options = None
  _globals['_QUERYTOTALTIMEOUTFEESRESPONSE'].fields_by_name['timeout_fees']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYFEEENABLEDCHANNELSRESPONSE'].fields_by_name['fee_enabled_channels']._loaded_options = None
  _globals['_QUERYFEEENABLEDCHANNELSRESPONSE'].fields_by_name['fee_enabled_channels']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['IncentivizedPackets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IncentivizedPackets']._serialized_options = b'\202\323\344\223\002\'\022%/ibc/apps/fee/v1/incentivized_packets'
  _globals['_QUERY'].methods_by_name['IncentivizedPacket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IncentivizedPacket']._serialized_options = b'\202\323\344\223\002\177\022}/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/incentivized_packet'
  _globals['_QUERY'].methods_by_name['IncentivizedPacketsForChannel']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IncentivizedPacketsForChannel']._serialized_options = b'\202\323\344\223\002M\022K/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/incentivized_packets'
  _globals['_QUERY'].methods_by_name['TotalRecvFees']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TotalRecvFees']._serialized_options = b'\202\323\344\223\002{\022y/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_recv_fees'
  _globals['_QUERY'].methods_by_name['TotalAckFees']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TotalAckFees']._serialized_options = b'\202\323\344\223\002z\022x/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_ack_fees'
  _globals['_QUERY'].methods_by_name['TotalTimeoutFees']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TotalTimeoutFees']._serialized_options = b'\202\323\344\223\002~\022|/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_timeout_fees'
  _globals['_QUERY'].methods_by_name['Payee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Payee']._serialized_options = b'\202\323\344\223\002A\022?/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/payee'
  _globals['_QUERY'].methods_by_name['CounterpartyPayee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CounterpartyPayee']._serialized_options = b'\202\323\344\223\002N\022L/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/counterparty_payee'
  _globals['_QUERY'].methods_by_name['FeeEnabledChannels']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeEnabledChannels']._serialized_options = b'\202\323\344\223\002\036\022\034/ibc/apps/fee/v1/fee_enabled'
  _globals['_QUERY'].methods_by_name['FeeEnabledChannel']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeEnabledChannel']._serialized_options = b'\202\323\344\223\002D\022B/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/fee_enabled'
  _globals['_QUERYINCENTIVIZEDPACKETSREQUEST']._serialized_start=302
  _globals['_QUERYINCENTIVIZEDPACKETSREQUEST']._serialized_end=442
  _globals['_QUERYINCENTIVIZEDPACKETSRESPONSE']._serialized_start=445
  _globals['_QUERYINCENTIVIZEDPACKETSRESPONSE']._serialized_end=656
  _globals['_QUERYINCENTIVIZEDPACKETREQUEST']._serialized_start=659
  _globals['_QUERYINCENTIVIZEDPACKETREQUEST']._serialized_end=792
  _globals['_QUERYINCENTIVIZEDPACKETRESPONSE']._serialized_start=795
  _globals['_QUERYINCENTIVIZEDPACKETRESPONSE']._serialized_end=930
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELREQUEST']._serialized_start=933
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELREQUEST']._serialized_end=1139
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELRESPONSE']._serialized_start=1142
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELRESPONSE']._serialized_end=1357
  _globals['_QUERYTOTALRECVFEESREQUEST']._serialized_start=1359
  _globals['_QUERYTOTALRECVFEESREQUEST']._serialized_end=1452
  _globals['_QUERYTOTALRECVFEESRESPONSE']._serialized_start=1455
  _globals['_QUERYTOTALRECVFEESRESPONSE']._serialized_end=1589
  _globals['_QUERYTOTALACKFEESREQUEST']._serialized_start=1591
  _globals['_QUERYTOTALACKFEESREQUEST']._serialized_end=1683
  _globals['_QUERYTOTALACKFEESRESPONSE']._serialized_start=1686
  _globals['_QUERYTOTALACKFEESRESPONSE']._serialized_end=1817
  _globals['_QUERYTOTALTIMEOUTFEESREQUEST']._serialized_start=1819
  _globals['_QUERYTOTALTIMEOUTFEESREQUEST']._serialized_end=1915
  _globals['_QUERYTOTALTIMEOUTFEESRESPONSE']._serialized_start=1918
  _globals['_QUERYTOTALTIMEOUTFEESRESPONSE']._serialized_end=2061
  _globals['_QUERYPAYEEREQUEST']._serialized_start=2063
  _globals['_QUERYPAYEEREQUEST']._serialized_end=2139
  _globals['_QUERYPAYEERESPONSE']._serialized_start=2141
  _globals['_QUERYPAYEERESPONSE']._serialized_end=2198
  _globals['_QUERYCOUNTERPARTYPAYEEREQUEST']._serialized_start=2200
  _globals['_QUERYCOUNTERPARTYPAYEEREQUEST']._serialized_end=2288
  _globals['_QUERYCOUNTERPARTYPAYEERESPONSE']._serialized_start=2290
  _globals['_QUERYCOUNTERPARTYPAYEERESPONSE']._serialized_end=2369
  _globals['_QUERYFEEENABLEDCHANNELSREQUEST']._serialized_start=2372
  _globals['_QUERYFEEENABLEDCHANNELSREQUEST']._serialized_end=2511
  _globals['_QUERYFEEENABLEDCHANNELSRESPONSE']._serialized_start=2514
  _globals['_QUERYFEEENABLEDCHANNELSRESPONSE']._serialized_end=2720
  _globals['_QUERYFEEENABLEDCHANNELREQUEST']._serialized_start=2722
  _globals['_QUERYFEEENABLEDCHANNELREQUEST']._serialized_end=2809
  _globals['_QUERYFEEENABLEDCHANNELRESPONSE']._serialized_start=2811
  _globals['_QUERYFEEENABLEDCHANNELRESPONSE']._serialized_end=2876
  _globals['_QUERY']._serialized_start=2879
  _globals['_QUERY']._serialized_end=5157
# @@protoc_insertion_point(module_scope)
